@@ -621,8 +621,8 @@ load_emit_signal_done (gpointer data)
 		}
 		else {
 			g_signal_emit (G_OBJECT (img), eog_image_signals [SIGNAL_LOADING_CANCELLED], 0);
-	}
-	
+		}
+		
 		break;
 
 	case EOG_IMAGE_STATUS_LOADED:
@@ -638,6 +638,8 @@ load_emit_signal_done (gpointer data)
 	}
 	g_signal_emit (G_OBJECT (img), eog_image_signals [SIGNAL_PROGRESS], 0, img->priv->progress);
 
+	/* release reference we had for loading process */
+	g_object_unref (img);
 
 	return FALSE;
 }
@@ -676,8 +678,10 @@ static EogMetadataReader*
 check_for_metadata_img_format (EogImage *img, guchar *buffer, int bytes_read)
 {
 	EogMetadataReader *md_reader = NULL;
-	
+
+#ifdef DEBUG	
 	g_print ("check img format for jpeg: %x%x - length: %i\n", buffer[0], buffer[1], bytes_read);
+#endif
 	
 	if (bytes_read >= 2) {
 		/* SOI (start of image) marker for JPEGs is 0xFFD8 */
